@@ -12,7 +12,6 @@
 #define _OKULAR_PAGE_PRIVATE_H_
 
 // qt/kde includes
-#include <QLinkedList>
 #include <QMap>
 #include <QString>
 #include <QTransform>
@@ -158,7 +157,7 @@ public:
     TextPage *m_text;
     PageTransition *m_transition;
     HighlightAreaRect *m_textSelections;
-    QLinkedList<FormField *> formfields;
+    QList<FormField *> formfields;
     Action *m_openingAction;
     Action *m_closingAction;
     double m_duration;
