@@ -199,13 +199,13 @@ private:
     //! Encode the string with the currently selected text codec, if possible. Or return as-is, if not.
     inline QString encodeWithCurrentCodec(const QByteArray &str) const
     {
-        return (m_textCodec ? m_textCodec->toUnicode(str.constData()) : str);
+        return (m_textCodec ? m_textCodec->toUnicode(str.constData()) : QString::fromUtf8(str));
     }
 
     //! Encode the string with the currently selected text codec, if possible. Or return as-is, if not.
     inline QString encodeWithCurrentCodec(const char *str) const
     {
-        return (m_textCodec ? m_textCodec->toUnicode(str) : (QString)str);
+        return (m_textCodec ? m_textCodec->toUnicode(str) : QString::fromUtf8(str));
     }
 
     //! Encode the string from internal files with the currently selected text codec, if possible.
@@ -219,7 +219,7 @@ private:
     //! Or return as-is, if not.
     inline QString encodeInternalWithCurrentCodec(const char *str) const
     {
-        return (m_textCodecForSpecialFiles ? m_textCodecForSpecialFiles->toUnicode(str) : (QString)str);
+        return (m_textCodecForSpecialFiles ? m_textCodecForSpecialFiles->toUnicode(str) : QString::fromUtf8(str));
     }
 
     //! Helper. Translates from Win32 encodings to generic wxWidgets ones.
