@@ -22,6 +22,7 @@
 #include <QDir>
 #include <QFile>
 #include <QImage>
+#include <QImageReader>
 #include <QLayout>
 #include <QMutex>
 #include <QPainter>
@@ -56,6 +57,7 @@
 #include "annots.h"
 #include "debug_pdf.h"
 #include "formfields.h"
+#include "imagescaling.h"
 #include "pdfsettingswidget.h"
 #include "pdfsignatureutils.h"
 #include "popplerembeddedfile.h"
@@ -104,6 +106,14 @@ public:
         m_scaleMode->setToolTip(i18n("Scaling mode for the printed pages"));
         printBackendLayout->addRow(i18n("Scale mode:"), m_scaleMode);
 
+        // Set scale mode to users default
+        m_scaleMode->setCurrentIndex(PDFSettings::printScaleMode());
+
+        // Set rasterizing if scale mode is 1 or 2
+        if (m_scaleMode->currentIndex() != 0) {
+            m_forceRaster->setCheckState(Qt::Checked);
+        }
+
         // If the user selects a scaling mode that requires the use of the
         // "Force rasterization" feature, enable it automatically so they don't
         // have to 1) know this and 2) do it manually
@@ -640,6 +650,12 @@ PDFGenerator::PDFGenerator(QObject *parent, const QVariantList &args)
     if (!PDFSettings::useDefaultCertDB()) {
         Poppler::setNSSDir(QUrl(PDFSettings::dBCertificatePath()).toLocalFile());
     }
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 06, 0)
+    auto activeBackend = PDFSettingsWidget::settingStringToPopplerEnum(PDFSettings::signatureBackend());
+    if (activeBackend) {
+        Poppler::setActiveCryptoSignBackend(activeBackend.value());
+    }
+#endif
 }
 
 PDFGenerator::~PDFGenerator()
@@ -1365,6 +1381,8 @@ void PDFGenerator::okularToPoppler(const Okular::NewSignatureData &oData, Popple
     pData->setBoundingRectangle({bRect.left, bRect.top, bRect.width(), bRect.height()});
     pData->setFontColor(Qt::black);
     pData->setBorderColor(Qt::black);
+    pData->setReason(oData.reason());
+    pData->setLocation(oData.location());
     pData->setDocumentOwnerPassword(oData.documentPassword().toLatin1());
     pData->setDocumentUserPassword(oData.documentPassword().toLatin1());
 }
@@ -1618,10 +1636,24 @@ bool PDFGenerator::setDocumentRenderHints()
 #undef SET_HINT
     // load thin line mode
     const int thinLineMode = PDFSettings::enhanceThinLines();
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 07, 0)
+    const bool enableOverprintPreview = PDFSettings::overprintPreviewEnabled();
+#endif
     const bool enableThinLineSolid = thinLineMode == PDFSettings::EnumEnhanceThinLines::Solid;
     const bool enableShapeLineSolid = thinLineMode == PDFSettings::EnumEnhanceThinLines::Shape;
+
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 07, 0)
+    const bool overprintPreviewWasEnabled = (oldhints & Poppler::Document::OverprintPreview) == Poppler::Document::OverprintPreview;
+#endif
     const bool thinLineSolidWasEnabled = (oldhints & Poppler::Document::ThinLineSolid) == Poppler::Document::ThinLineSolid;
     const bool thinLineShapeWasEnabled = (oldhints & Poppler::Document::ThinLineShape) == Poppler::Document::ThinLineShape;
+
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 07, 0)
+    if (enableOverprintPreview != overprintPreviewWasEnabled) {
+        pdfdoc->setRenderHint(Poppler::Document::OverprintPreview, enableOverprintPreview);
+        changed = true;
+    }
+#endif
     if (enableThinLineSolid != thinLineSolidWasEnabled) {
         pdfdoc->setRenderHint(Poppler::Document::ThinLineSolid, enableThinLineSolid);
         changed = true;
@@ -1997,11 +2029,22 @@ Okular::AnnotationProxy *PDFGenerator::annotationProxy() const
 
 bool PDFGenerator::canSign() const
 {
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 06, 0)
+    return !Poppler::availableCryptoSignBackends().empty();
+#else
     return Poppler::hasNSSSupport();
+#endif
 }
 
 bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rFilename)
 {
+    // We need a temporary file to pass a prepared image to poppler
+    QTemporaryFile timg(QFileInfo(rFilename).absolutePath() + QLatin1String("/okular_XXXXXX.png"));
+    timg.setAutoRemove(true);
+    if (!timg.open()) {
+        return false;
+    }
+
     // save to tmp file - poppler doesn't like overwriting in-place
     QTemporaryFile tf(QFileInfo(rFilename).absolutePath() + QLatin1String("/okular_XXXXXX.pdf"));
     tf.setAutoRemove(false);
@@ -2014,6 +2057,29 @@ bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rF
 
     Poppler::PDFConverter::NewSignatureData pData;
     okularToPoppler(oData, &pData);
+    if (!oData.backgroundImagePath().isEmpty() && QFile::exists(oData.backgroundImagePath())) {
+        // width and height for target image
+        const Okular::NormalizedRect bRect = oData.boundingRectangle();
+        // 2 is an experimental decided upon fudge factor to compensate for the fact that pageSize is in points
+        // but most of this ends up working in pixels anyway
+        double width = pdfdoc->page(oData.page())->pageSizeF().width() * bRect.width() * 2;
+        double height = pdfdoc->page(oData.page())->pageSizeF().height() * bRect.height() * 2;
+
+        QImageReader reader(oData.backgroundImagePath());
+        QSize imageSize = reader.size();
+        if (!reader.size().isNull()) {
+            reader.setScaledSize(imageSize.scaled(width, height, Qt::KeepAspectRatio));
+        }
+        auto input = reader.read();
+        if (!input.isNull()) {
+            auto scaled = imagescaling::scaleAndFitCanvas(input, QSize(width, height));
+            bool success = scaled.save(timg.fileName(), "png");
+            if (success) {
+                pData.setImagePath(timg.fileName());
+                pData.setBackgroundColor(Qt::white);
+            }
+        }
+    }
     if (!converter->sign(pData)) {
         tf.remove();
         return false;
