@@ -11,6 +11,10 @@
 #include <QWidget>
 
 #include "ui_pdfsettingswidget.h"
+#include <poppler-form.h>
+#include <poppler-version.h>
+
+#define POPPLER_VERSION_MACRO ((POPPLER_VERSION_MAJOR << 16) | (POPPLER_VERSION_MINOR << 8) | (POPPLER_VERSION_MICRO))
 
 class QTreeWidget;
 
@@ -21,6 +25,10 @@ class PDFSettingsWidget : public QWidget
 public:
     explicit PDFSettingsWidget(QWidget *parent = nullptr);
     bool event(QEvent *e) override;
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 06, 0)
+    static std::optional<Poppler::CryptoSignBackend> settingStringToPopplerEnum(QStringView string);
+    static QString popplerEnumToSettingString(Poppler::CryptoSignBackend backend);
+#endif
 
 private:
     void warnRestartNeeded();
