@@ -23,7 +23,7 @@
 #include "core/signatureutils.h"
 
 struct SignatureItem {
-    enum DataType { Root, RevisionInfo, ValidityStatus, SigningTime, Reason, FieldInfo };
+    enum DataType { Root, RevisionInfo, ValidityStatus, SigningTime, Reason, Location, FieldInfo };
 
     SignatureItem();
     SignatureItem(SignatureItem *parent, const Okular::FormFieldSignature *form, DataType type, int page);
@@ -155,13 +155,18 @@ void SignatureModelPrivate::notifySetup(const QVector<Okular::Page *> &pages, in
             childItem1->displayString = SignatureGuiUtils::getReadableSignatureStatus(info.signatureStatus());
 
             auto childItem2 = new SignatureItem(parentItem, nullptr, SignatureItem::SigningTime, pageNumber);
-            childItem2->displayString = i18n("Signing Time: %1", info.signingTime().toString(Qt::DefaultLocaleLongDate));
+            childItem2->displayString = i18n("Signing Time: %1", QLocale().toString(info.signingTime(), QLocale::LongFormat));
 
             const QString reason = info.reason();
             if (!reason.isEmpty()) {
                 auto childItem3 = new SignatureItem(parentItem, nullptr, SignatureItem::Reason, pageNumber);
                 childItem3->displayString = i18n("Reason: %1", reason);
             }
+            const QString location = info.location();
+            if (!location.isEmpty()) {
+                auto childItem3 = new SignatureItem(parentItem, nullptr, SignatureItem::Location, pageNumber);
+                childItem3->displayString = i18n("Location: %1", location);
+            }
 
             auto childItem4 = new SignatureItem(parentItem, sf, SignatureItem::FieldInfo, pageNumber);
             childItem4->displayString = i18n("Field: %1 on page %2", sf->name(), pageNumber + 1);
@@ -249,7 +254,7 @@ QVariant SignatureModel::data(const QModelIndex &index, int role) const
     case SignerNameRole:
         return form->signatureInfo().signerName();
     case SigningTimeRole:
-        return form->signatureInfo().signingTime().toString(Qt::DefaultLocaleLongDate);
+        return QLocale().toString(form->signatureInfo().signingTime(), QLocale::LongFormat);
     case SigningLocationRole:
         return form->signatureInfo().location();
     case SigningReasonRole:
