@@ -370,14 +370,19 @@ public:
             }
         }
 
-        const std::unique_ptr<Okular::CertificateInfo> cert = SignaturePartUtils::getCertificateAndPasswordForSigning(m_pageView, m_document, &passToUse, &documentPassword);
-        if (!cert) {
+        const auto signInfo = SignaturePartUtils::getCertificateAndPasswordForSigning(m_pageView, m_document, SignaturePartUtils::SigningInformationOption::BackgroundImage);
+        if (!signInfo) {
             m_aborted = true;
             passToUse.clear();
             documentPassword.clear();
         } else {
-            certNicknameToUse = cert->nickName();
-            certCommonName = cert->subjectInfo(Okular::CertificateInfo::CommonName);
+            certNicknameToUse = signInfo->certificate->nickName();
+            certCommonName = signInfo->certificate->subjectInfo(Okular::CertificateInfo::CommonName, Okular::CertificateInfo::EmptyString::TranslatedNotAvailable);
+            passToUse = signInfo->certificatePassword;
+            documentPassword = signInfo->documentPassword;
+            reason = signInfo->reason;
+            location = signInfo->location;
+            backgroundImagePath = signInfo->backgroundImagePath;
         }
 
         m_creationCompleted = false;
@@ -410,6 +415,9 @@ public:
         data.setDocumentPassword(documentPassword);
         data.setPage(m_page->number());
         data.setBoundingRectangle(rect);
+        data.setReason(reason);
+        data.setLocation(location);
+        data.setBackgroundImagePath(backgroundImagePath);
         passToUse.clear();
         documentPassword.clear();
         return m_document->sign(data, newFilePath);
@@ -420,6 +428,9 @@ private:
     QString certCommonName;
     QString passToUse;
     QString documentPassword;
+    QString location;
+    QString backgroundImagePath;
+    QString reason;
 
     Okular::Document *m_document;
     const Okular::Page *m_page;
