@@ -17,7 +17,6 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRandom>
 #include <KSelectAction>
 #include <QAction>
 #include <QApplication>
@@ -30,6 +29,7 @@
 #include <QLabel>
 #include <QLayout>
 #include <QPainter>
+#include <QRandomGenerator>
 #include <QScreen>
 #include <QStyle>
 #include <QStyleOption>
@@ -1853,7 +1853,7 @@ const Okular::PageTransition PresentationWidget::defaultTransition(int type) con
         break;
     }
     case Okular::Settings::EnumSlidesTransition::Random: {
-        return defaultTransition(KRandom::random() % 18);
+        return defaultTransition(QRandomGenerator::global()->bounded(18));
         break;
     }
     case Okular::Settings::EnumSlidesTransition::SplitHorizontalIn: {
