@@ -58,20 +58,27 @@ QString serializeOptions(const QCommandLineParser &args)
     const bool noRaise = args.isSet(QStringLiteral("noraise"));
     const QString page = args.value(QStringLiteral("page"));
     const QString find = args.value(QStringLiteral("find"));
+    const QString editorCmd = args.value(QStringLiteral("editor-cmd"));
 
-    return serializeOptions(startInPresentation, showPrintDialog, showPrintDialogAndExit, unique, noRaise, page, find);
+    return serializeOptions(startInPresentation, showPrintDialog, showPrintDialogAndExit, unique, noRaise, page, find, editorCmd);
 }
 
-QString serializeOptions(bool startInPresentation, bool showPrintDialog, bool showPrintDialogAndExit, bool unique, bool noRaise, const QString &page, const QString &find)
+QString serializeOptions(bool startInPresentation, bool showPrintDialog, bool showPrintDialogAndExit, bool unique, bool noRaise, const QString &page, const QString &find, const QString &editorCmd)
 {
-    return QStringLiteral("%1:%2:%3:%4:%5:%6:%7").arg(startInPresentation).arg(showPrintDialog).arg(showPrintDialogAndExit).arg(unique).arg(noRaise).arg(page, QString::fromLatin1(find.toUtf8().toBase64()));
+    return QStringLiteral("%1:%2:%3:%4:%5:%6:%7:%8")
+        .arg(startInPresentation)
+        .arg(showPrintDialog)
+        .arg(showPrintDialogAndExit)
+        .arg(unique)
+        .arg(noRaise)
+        .arg(page, QString::fromLatin1(find.toUtf8().toBase64()), QString::fromLatin1(editorCmd.toUtf8().toBase64()));
 }
 
-bool unserializeOptions(const QString &serializedOptions, bool *presentation, bool *print, bool *print_and_exit, bool *unique, bool *noraise, QString *page, QString *find)
+static bool unserializeOptions(const QString &serializedOptions, bool *presentation, bool *print, bool *print_and_exit, bool *unique, bool *noraise, QString *page, QString *find, QString *editorCmd)
 {
     const QStringList args = serializedOptions.split(QStringLiteral(":"));
 
-    if (args.count() == 7) {
+    if (args.count() >= 8) {
         *presentation = args[0] == QLatin1String("1");
         *print = args[1] == QLatin1String("1");
         *print_and_exit = args[2] == QLatin1String("1");
@@ -79,6 +86,7 @@ bool unserializeOptions(const QString &serializedOptions, bool *presentation, bo
         *noraise = args[4] == QLatin1String("1");
         *page = args[5];
         *find = args[6];
+        *editorCmd = args[7];
         return true;
     }
     return false;
@@ -88,42 +96,42 @@ bool startInPresentation(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &result, &dummy, &dummy, &dummy, &dummy, &dummyString, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &result, &dummy, &dummy, &dummy, &dummy, &dummyString, &dummyString, &dummyString) && result;
 }
 
 bool showPrintDialog(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &result, &dummy, &dummy, &dummy, &dummyString, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &result, &dummy, &dummy, &dummy, &dummyString, &dummyString, &dummyString) && result;
 }
 
 bool showPrintDialogAndExit(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &dummy, &result, &dummy, &dummy, &dummyString, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &dummy, &result, &dummy, &dummy, &dummyString, &dummyString, &dummyString) && result;
 }
 
 bool unique(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &result, &dummy, &dummyString, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &result, &dummy, &dummyString, &dummyString, &dummyString) && result;
 }
 
 bool noRaise(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &result, &dummyString, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &result, &dummyString, &dummyString, &dummyString) && result;
 }
 
 QString page(const QString &serializedOptions)
 {
     QString result, dummyString;
     bool dummy;
-    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &result, &dummyString);
+    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &result, &dummyString, &dummyString);
     return result;
 }
 
@@ -131,8 +139,15 @@ QString find(const QString &serializedOptions)
 {
     QString result, dummyString;
     bool dummy;
-    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &dummyString, &result);
+    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &dummyString, &result, &dummyString);
     return QString::fromUtf8(QByteArray::fromBase64(result.toLatin1()));
 }
 
+QString editorCmd(const QString &serializedOptions)
+{
+    QString result, dummyString;
+    bool dummy;
+    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &dummyString, &dummyString, &result);
+    return QString::fromUtf8(QByteArray::fromBase64(result.toLatin1()));
+}
 }
